@@ -4,14 +4,11 @@ Reusable methods throughout DYC
 import os
 import yaml
 import string
-INDENT_OPTIONS = {
-    'tab': '\t',
-    '2 spaces': '  ',
-    'False': '',
-}
+
+INDENT_OPTIONS = {"tab": "\t", "2 spaces": "  ", "False": ""}
 
 
-def get_leading_whitespace(s): 
+def get_leading_whitespace(s):
     """
     Gets the leading whitespace of a string. Mainly used to
     determine how many space were there originally before adding a
@@ -21,13 +18,13 @@ def get_leading_whitespace(s):
     ----------
     str s: String text
     """
-    accumulator = [] 
-    for c in s: 
-        if c in ' \t\v\f\r\n': 
-            accumulator.append(c) 
-        else: 
-            break 
-    return ''.join(accumulator) 
+    accumulator = []
+    for c in s:
+        if c in " \t\v\f\r\n":
+            accumulator.append(c)
+        else:
+            break
+    return "".join(accumulator)
 
 
 def read_yaml(path):
@@ -38,7 +35,7 @@ def read_yaml(path):
     str path: path of file
     """
     try:
-        with open(path, 'r') as config:
+        with open(path, "r") as config:
             try:
                 return yaml.safe_load(config)
             except yaml.YAMLError as exc:
@@ -48,8 +45,8 @@ def read_yaml(path):
 
 
 class BlankFormatter(string.Formatter):
-    def __init__(self, default=''):
-        self.default=default
+    def __init__(self, default=""):
+        self.default = default
 
     def get_value(self, key, args, kwds):
         if isinstance(key, str):
@@ -68,9 +65,10 @@ def get_indent(space):
     """
     value = INDENT_OPTIONS.get(str(space))
     if value is None:
-        return '    '
+        return "    "
     return value
 
+
 def get_extension(filename):
     """
     Gets the extension of a file
@@ -79,9 +77,9 @@ def get_extension(filename):
     str filename: the filename to extract extension from
     """
     try:
-        return os.path.splitext(filename)[1].replace('.', '')
-    except AttributeError:
-        return ''
+        return os.path.splitext(filename)[1].replace(".", "")
+    except (AttributeError, TypeError):
+        return ""
 
 
 def all_files_generator(extensions=[]):
@@ -93,10 +91,12 @@ def all_files_generator(extensions=[]):
     list extensions: Allowed extensions on a file
     """
     for root, dirs, files in os.walk(os.getcwd()):
-        files = [os.path.join(root, f) for f in files if not f[0] == '.']
-        dirs[:] = [d for d in dirs if not d[0] == '.']
-        if len(extensions):
-            files = [filename for filename in files if get_extension(filename) in extensions]
+        files = [os.path.join(root, f) for f in files if not f[0] == "."]
+        dirs[:] = [d for d in dirs if not d[0] == "."]
+        if extensions:
+            files = [
+                filename for filename in files if get_extension(filename) in extensions
+            ]
         yield files
 
 
@@ -110,9 +110,9 @@ def add_start_end(string):
     str string: large text
     """
     leading_space = get_leading_whitespace(string)
-    start = '{}## START\n'.format(leading_space)
-    end = '\n{}## END'.format(leading_space)
-    string.split('\n')
+    start = "{}## START\n".format(leading_space)
+    end = "\n{}## END".format(leading_space)
+    string.split("\n")
     result = start + string + end
     return result
 
@@ -125,7 +125,7 @@ def get_file_lines(name):
     str name: filepath and name of file
     """
     lines = 0
-    with open(name, 'r') as stream:
+    with open(name, "r") as stream:
         lines = len(stream.readlines())
     return lines
 
@@ -138,7 +138,8 @@ def get_hunk(patch):
     str patch: Diff patched text
     """
     import re
-    pat = r'.*?\@\@(.*)\@\@.*'
+
+    pat = r".*?\@\@(.*)\@\@.*"
     match = re.findall(pat, patch)
     return [m.strip() for m in match]
 
@@ -150,9 +151,25 @@ def get_additions_in_first_hunk(hunk):
     ----------
     str hunk: Git diff Hunk
     """
-    if not isinstance(hunk, list): return None, None
-    if len(hunk) < 1: return None, None
-    adds_patch = hunk[0].split('+')[-1].split(',')
+    if not isinstance(hunk, list):
+        return None, None
+    if len(hunk) < 1:
+        return None, None
+    adds_patch = hunk[0].split("+")[-1].split(",")
     start = int(adds_patch[0])
     end = int(start) + int(adds_patch[1])
     return start, end
+
+
+def is_one_line_method(line, keywords):
+    """
+    Gets True if the line holds a complete method declaration (from 'def to :), 
+    otherwise it gets False
+    ----------
+    str line: Text line
+    list keywords: list of keywords like def for python, func for go etc.
+    """
+    found = [word.lstrip() for word in line.split(" ") if word.lstrip() in keywords]
+    if found:
+        return line.count("(") == line.count(")")
+    return bool(found)
